@@ -1,5 +1,8 @@
 def main():
-    from showip.showip import getdata
+    try:
+        from showip.showip import getdata, dns
+    except ModuleNotFoundError:
+        from showip import getdata, dns
     import argparse
 
     parser = argparse.ArgumentParser(description='Get information about your IP or any other IP')
@@ -7,4 +10,10 @@ def main():
     args = parser.parse_args()
 
     data = getdata(args.ip)
-    print(f'IP: {data["query"]}\nCountry: {data["country"]}, {data["countryCode"]}\nRegion: {data["regionName"]}, {data["region"]}\nCity: {data["city"]}\nISP: {data["isp"]}\nReverse: {data["reverse"]}')
\ No newline at end of file
+    dns = dns()
+    print(f'IP: {data["query"]}\nCountry: {data["country"]}, {data["countryCode"]}\nRegion: {data["regionName"]}, {data["region"]}\nCity: {data["city"]}\nISP: {data["isp"]}\nReverse: {data["reverse"]}')
+    if args.ip == None:
+        print("----------------------------")
+        print(f"DNS: {dns['dns']['ip']}({dns['dns']['geo']})")
+if __name__ == "__main__":
+    main()
\ No newline at end of file
